////////////////////////////////////////////////////////////////////////////////////
//
// NyanCanSystem v2c - NyanCanSpeedInventory
//
////////////////////////////////////////////////////////////////////////////////////

class NyanCanSpeedInventory expands RelicInventory;

#exec MESH IMPORT MESH=NyanCanSpeed ANIVFILE=MODELS\NyanCatCan_a.3d DATAFILE=MODELS\NyanCatCan_d.3d X=0 Y=0 Z=0
#exec MESH ORIGIN MESH=NyanCanSpeed X=0 Y=0 Z=0
#exec MESH SEQUENCE MESH=NyanCanSpeed SEQ=All STARTFRAME=0 NUMFRAMES=1
#exec MESH SEQUENCE MESH=NyanCanSpeed SEQ=Still STARTFRAME=0 NUMFRAMES=1
#exec MESHMAP NEW MESHMAP=NyanCanSpeed MESH=NyanCanSpeed 
#exec MESHMAP SCALE MESHMAP=NyanCanSpeed X=0.4 Y=0.4 Z=0.80
#exec TEXTURE IMPORT NAME=NyanCanSpeedBody FILE=Textures\CanSkins\NyanCanSpeedBody.bmp GROUP=CanSkins lodset=2 
#exec TEXTURE IMPORT NAME=NyanCanSpeedTop FILE=Textures\CanSkins\NyanCanSpeedTop.bmp GROUP=CanSkins lodset=2 
#exec MESHMAP SETTEXTURE MESHMAP=NyanCanSpeed NUM=0 TEXTURE=NyanCanSystem2c.CanSkins.NyanCanSpeedBody
#exec MESHMAP SETTEXTURE MESHMAP=NyanCanSpeed NUM=1 TEXTURE=NyanCanSystem2c.CanSkins.NyanCanSpeedTop

#exec AUDIO IMPORT FILE=Sounds\NyanCanSpeed.wav NAME=NyanCanSpeedSound GROUP=NyanCanSounds

function PickupFunction(Pawn Other)
{
	Super.PickupFunction(Other);

	ShellEffect = Spawn(ShellType, Owner,,Owner.Location, Owner.Rotation); 
}

state Activated
{
	function BeginState()
	{
		SetTimer(0.2, True);

		Super.BeginState();

		// Alter player's stats.
		Pawn(Owner).AirControl = 0.65;
		Pawn(Owner).JumpZ *= 1.1;
		Pawn(Owner).GroundSpeed *= 1.3;
		Pawn(Owner).WaterSpeed *= 1.3;
		Pawn(Owner).AirSpeed *= 1.3;
		Pawn(Owner).Acceleration *= 1.3;

		// Add wind blowing.
		Pawn(Owner).AmbientSound = sound'NyanCanSpeedSound';
		Pawn(Owner).SoundRadius = 64;
	}

	function EndState()
	{
		local float SpeedScale;
		SetTimer(0.0, False);

		Super.EndState();

		if ( Level.Game.IsA('DeathMatchPlus') && DeathMatchPlus(Level.Game).bMegaSpeed )
			SpeedScale = 1.3;
		else
			SpeedScale = 1.0;

		// Restore player's stats.
		Pawn(Owner).AirControl = DeathMatchPlus(Level.Game).AirControl;
		Pawn(Owner).JumpZ = Pawn(Owner).Default.JumpZ * Level.Game.PlayerJumpZScaling();
		Pawn(Owner).GroundSpeed = Pawn(Owner).Default.GroundSpeed * SpeedScale;
		Pawn(Owner).WaterSpeed = Pawn(Owner).Default.WaterSpeed * SpeedScale;
		Pawn(Owner).AirSpeed = Pawn(Owner).Default.AirSpeed * SpeedScale;
		Pawn(Owner).Acceleration = Pawn(Owner).Default.Acceleration * SpeedScale;

		// Remove sound.
		Pawn(Owner).AmbientSound = None;
	}
}

defaultproperties
{
    ItemName="Nyan Can Speed"
    DrawType=DT_Mesh
    bRotatingPickup=True
    ShellType=Class'speedshell'
    PickupMessage="You picked up the Nyan Can of Speed!"
    PickupViewMesh=Mesh'NyanCanSpeed'
    Mesh=LodMesh'NyanCanSpeed'
    PickupViewScale=0.50
    Icon=Texture'NyanCanSystem2c.Icons.NyanIconSpeed'
    Physics=5
    CollisionHeight=40.00
    Rotation=(Pitch=15000,Yaw=15000,Roll=15000)
    RotationRate=(Pitch=15000,Yaw=15000,Roll=15000)
}

