////////////////////////////////////////////////////////////////////////////////////
//
// NyanCanSystem v2c - RelicInventory
//
////////////////////////////////////////////////////////////////////////////////////

class RelicInventory expands TournamentPickup;

#exec TEXTURE IMPORT NAME=NyanIconSpeed FILE=Textures\Icons\IconSpeed2.bmp GROUP=Icons
#exec TEXTURE IMPORT NAME=NyanIconJump FILE=Textures\Icons\IconJump2.bmp GROUP=Icons
#exec TEXTURE IMPORT NAME=NyanIconRegenHealth FILE=Textures\Icons\IconRegenHealth2.bmp GROUP=Icons
#exec TEXTURE IMPORT NAME=NyanIconRegenAmmo FILE=Textures\Icons\IconRegenAmmo2.bmp GROUP=Icons
#exec TEXTURE IMPORT NAME=NyanIconRedemption FILE=Textures\Icons\IconRedemption2.bmp GROUP=Icons
#exec TEXTURE IMPORT NAME=NyanIconGhost FILE=Textures\Icons\IconGhost2.bmp GROUP=Icons

#exec AUDIO IMPORT FILE=Sounds\NyanCanInventoryPickup.wav NAME=NyanCanInventoryPickup

var Relic MyRelic;
var float IdleTime;
var RelicShell ShellEffect;
var texture ShellSkin;
var class<RelicShell> ShellType;

function Destroyed()
{
	if (ShellEffect != None)
		ShellEffect.Destroy();
	if ((MyRelic != None) && (MyRelic.SpawnedRelic == self))
		MyRelic.SpawnRelic(0);

	Super.Destroyed();
}

simulated function PostBeginPlay()
{
	Super.PostBeginPlay();

	if (Level.NetMode == NM_DedicatedServer)
		return;
	
	CheckForHUDMutator();
}

simulated function CheckForHUDMutator()
{
	local HUDMutator M;
	local RelicHUDMutator RHM;
	local PlayerPawn P;

	ForEach AllActors(class'PlayerPawn', P)
		if (P.myHUD != None)
		{
			// check if it already has a RelicHUDMutator
			M = HUDMutator(P.myHud.HUDMutator);
			while (M != None)
			{
				if (M.IsA('RelicHUDMutator'))
					return;
				M = M.NextRHUDMutator;
			}
			RHM = Spawn(class'RelicHUDMutator');
			RHM.RegisteraHUDMutator();
			if (RHM.bIsHUDMutator)
			{
				if (Role == ROLE_SimulatedProxy)
					SetTimer(0.0, false);
				return;
			}
			else
				RHM.Destroy();
		}	

	if (Role == ROLE_SimulatedProxy)
		SetTimer(1.0, true);
}

simulated function Timer()
{
	Super.Timer();
	if (Role == ROLE_SimulatedProxy)
		CheckForHUDMutator();
}

function bool HandlePickupQuery(inventory Item)
{
	if (Item.IsA('RelicInventory'))
		return True;
	else 
		return Super.HandlePickupQuery(Item);
}

auto state Pickup
{
	function BeginState()
	{
		Super.BeginState();
		IdleTime = 0;
		SetOwner(None);
	}

	function Touch(actor Other)
	{
		if (ValidTouch(Other)) 
		{
			bHeldItem = True;
			Instigator = Pawn(Other);
			CheckForHUDMutator();
			BecomeItem();
			Pawn(Other).AddInventory( Self );

			if (Level.Game.LocalLog != None)
				Level.Game.LocalLog.LogPickup(Self, Pawn(Other));
			if (Level.Game.WorldLog != None)
				Level.Game.WorldLog.LogPickup(Self, Pawn(Other));

			if (bActivatable && Pawn(Other).SelectedItem==None) 
				Pawn(Other).SelectedItem=Self;

			if (bActivatable && bAutoActivate && Pawn(Other).bAutoActivate) 
				Self.Activate();

			if (PickupMessageClass == None)
				Pawn(Other).ClientMessage(PickupMessage, 'Pickup');
			else
				Pawn(Other).ReceiveLocalizedMessage( PickupMessageClass, 0, None, None, Self.Class );
			PlaySound (PickupSound,,2.0);	
			PickupFunction(Pawn(Other));
		}
	}

	simulated function Landed(Vector HitNormal)
	{
		local rotator newRot;

		newRot = Rotation;
		newRot.pitch = 0;
		SetRotation(newRot);
		SetPhysics(PHYS_Rotating);
		IdleTime = 0;
		SetCollision( True, False, False );
	}
}

state Activated
{
	function EndState()
	{
	}

	function Timer()
	{
		if (Role == ROLE_SimulatedProxy)
			CheckForHUDMutator();
	}

	function BeginState()
	{
		IdleTime = 0;
	}
}

state DeActivated
{
Begin:
}

function DropInventory()
{
	local RelicInventory Dropped;
	local vector X,Y,Z;

	Dropped = Spawn(Class);
	Dropped.MyRelic = MyRelic;
	MyRelic.SpawnedRelic = Dropped;
	if (Owner != None )
	{
		Owner.GetAxes(Owner.Rotation,X,Y,Z);
		Dropped.SetLocation(Owner.Location + 0.8 * Owner.CollisionRadius * X + -0.5 * Owner.CollisionRadius * Y);
	}
	Dropped.RemoteRole	  = ROLE_SimulatedProxy;
	Dropped.Mesh          = PickupViewMesh;
	Dropped.DrawScale     = PickupViewScale;
	Dropped.bOnlyOwnerSee = false;
	Dropped.bHidden       = false;
	Dropped.bCarriedItem  = false;
	Dropped.NetPriority   = 1.4;
	Dropped.SetCollision(False, False, False);
	Dropped.SetPhysics(PHYS_Falling);
	Dropped.bCollideWorld = True;
	if (Owner != None)
		Dropped.Velocity = Vector(Pawn(Owner).ViewRotation) * 500 + vect(0,0,220);
	Dropped.GotoState('PickUp', 'Dropped');
	// Remove from player's inventory.
	Destroy();
}

function PickupFunction(Pawn Other)
{
	Super.PickupFunction(Other);

	LightType = LT_None;
}


function FlashShell(float Duration)
{
	if (ShellEffect == None)
	{
		//log("ShellType: " $ string(ShellType));
		ShellEffect = Spawn(ShellType, Owner,,Owner.Location, Owner.Rotation);
		//log("ShellEffect created");
	}

	if (ShellEffect != None)
	{
		ShellEffect.Mesh = Owner.Mesh;
		ShellEffect.DrawScale = Owner.Drawscale;
		ShellEffect.Texture = ShellSkin;
		ShellEffect.MultiSkins[1] = ShellSkin;
		//log("ShellSkin applied: " $ string(ShellSkin));
		ShellEffect.SetTimer(Duration, false);
	}
}

event float BotDesireability(pawn Bot)
{
	local Inventory Inv;

	// If we already have a Relic, we don't want another one.

	for(Inv=Bot.Inventory; Inv!=None; Inv=Inv.Inventory)   
		if ( Inv.IsA('RelicInventory') )
			return -1;

	return MaxDesireability;
}

defaultproperties
{
    ShellSkin=FireTexture'UnrealShare.Belt_fx.ShieldBelt.RedShield'
    ShellType=Class'RelicShell'
    bAutoActivate=True
    bActivatable=True
    PickupMessage="You picked up a null Nyan Can"
    PickupViewMesh=LodMesh'Botpack.DomN'
    MaxDesireability=3.00
    PickupSound=Sound'NyanCanSystem2c.NyanCanInventoryPickup'
    bUnlit=True
    CollisionRadius=15.00
    CollisionHeight=5.00
    LightEffect=13
    LightBrightness=255
    LightHue=170
    LightSaturation=255
    LightRadius=5
    LightPeriod=64
    LightPhase=255
    Mass=10.00
    Rotation=(Pitch=15000,Yaw=15000,Roll=15000)
    RotationRate=(Pitch=15000,Yaw=15000,Roll=15000)
}
